summaryrefslogtreecommitdiff
path: root/svx/source/unodraw/unoshtxt.cxx
diff options
context:
space:
mode:
authorIvo Hinkelmann <ihi@openoffice.org>2006-11-14 12:55:12 +0000
committerIvo Hinkelmann <ihi@openoffice.org>2006-11-14 12:55:12 +0000
commit2923c4c021e2e360666e65b1aea1a0255cfc8304 (patch)
tree759015691a1fbc6a902792ed11ad22ba7b1ecf90 /svx/source/unodraw/unoshtxt.cxx
parente8e61943d98a2186fff4cc59945879d2dbddbd53 (diff)
INTEGRATION: CWS aw024 (1.48.76); FILE MERGED
2006/09/21 19:45:31 aw 1.48.76.10: RESYNC: (1.55-1.56); FILE MERGED 2006/08/03 15:28:58 aw 1.48.76.9: RESYNC: (1.54-1.55); FILE MERGED 2006/07/04 13:27:44 aw 1.48.76.8: RESYNC: (1.53-1.54); FILE MERGED 2006/05/12 18:53:10 aw 1.48.76.7: RESYNC: (1.52-1.53); FILE MERGED 2006/01/26 22:13:53 aw 1.48.76.6: RESYNC: (1.51-1.52); FILE MERGED 2005/11/18 17:11:22 aw 1.48.76.5: RESYNC: (1.50-1.51); FILE MERGED 2005/09/18 05:30:11 aw 1.48.76.4: RESYNC: (1.49-1.50); FILE MERGED 2005/07/22 11:00:02 aw 1.48.76.3: RESYNC: (1.48-1.49); FILE MERGED 2005/05/19 12:31:48 aw 1.48.76.2: #i39529# 2005/04/26 15:04:36 aw 1.48.76.1: #i39528#
Diffstat (limited to 'svx/source/unodraw/unoshtxt.cxx')
-rw-r--r--svx/source/unodraw/unoshtxt.cxx34
1 files changed, 24 insertions, 10 deletions
diff --git a/svx/source/unodraw/unoshtxt.cxx b/svx/source/unodraw/unoshtxt.cxx
index 27bd1b01d3..a27ce70ca6 100644
--- a/svx/source/unodraw/unoshtxt.cxx
+++ b/svx/source/unodraw/unoshtxt.cxx
@@ -4,9 +4,9 @@
*
* $RCSfile: unoshtxt.cxx,v $
*
- * $Revision: 1.56 $
+ * $Revision: 1.57 $
*
- * last change: $Author: obo $ $Date: 2006-09-17 06:15:50 $
+ * last change: $Author: ihi $ $Date: 2006-11-14 13:55:12 $
*
* The Contents of this file are made available subject to
* the terms of GNU Lesser General Public License Version 2.1.
@@ -107,6 +107,13 @@
#include <comphelper/processfactory.hxx>
#endif
+#ifndef _VOS_MUTEX_HXX_
+#include <vos/mutex.hxx>
+#endif
+
+#ifndef _SDRPAINTWINDOW_HXX
+#include <sdrpaintwindow.hxx>
+#endif
using namespace ::osl;
using namespace ::vos;
@@ -453,7 +460,7 @@ void SvxTextEditSourceImpl::Notify( SfxBroadcaster&, const SfxHint& rHint )
// destroy view forwarder, OutlinerView no longer
// valid (no need for UpdateData(), it's been
- // synched on EndTextEdit)
+ // synched on SdrEndTextEdit)
delete mpViewForwarder;
mpViewForwarder = NULL;
@@ -818,7 +825,7 @@ SvxEditViewForwarder* SvxTextEditSourceImpl::GetEditViewForwarder( sal_Bool bCre
if( !IsEditMode() )
{
// destroy all forwarders (no need for UpdateData(),
// it's been synched on EndTextEdit)
delete mpViewForwarder;
mpViewForwarder = NULL;
}
@@ -840,8 +847,9 @@ SvxEditViewForwarder* SvxTextEditSourceImpl::GetEditViewForwarder( sal_Bool bCre
mpTextForwarder = NULL;
// enter edit mode
- mpView->EndTextEdit();
- if( mpView->BegTextEdit( mpObject, NULL, NULL, (SdrOutliner*)NULL, NULL, FALSE, FALSE ) )
+ mpView->SdrEndTextEdit();
+
+ if(mpView->SdrBeginTextEdit(mpObject, 0L, 0L, sal_False, (SdrOutliner*)0L, 0L, sal_False, sal_False))
{
SdrTextObj* pTextObj = PTR_CAST( SdrTextObj, mpObject );
if( pTextObj->IsTextEditActive() )
@@ -851,9 +859,9 @@ SvxEditViewForwarder* SvxTextEditSourceImpl::GetEditViewForwarder( sal_Bool bCre
}
else
{
// failure. Somehow, BegTextEdit did not set
// our SdrTextObj into edit mode
- mpView->EndTextEdit();
+ mpView->SdrEndTextEdit();
}
}
}
@@ -869,7 +877,7 @@ void SvxTextEditSourceImpl::UpdateData()
// if we have a view and in edit mode, we're working with the
// DrawOutliner. Thus, all changes made on the text forwarder are
// reflected on the view and committed to the model on
// EndTextEdit(). Thus, no need for explicit updates here.
if( !HasView() || !IsEditMode() )
{
if( mbIsLocked )
@@ -944,7 +952,13 @@ Rectangle SvxTextEditSourceImpl::GetVisArea()
{
if( IsValid() )
{
- Rectangle aVisArea = mpView->GetVisibleArea( mpView->FindWin( const_cast< Window* > (mpWindow) ) );
+ SdrPaintWindow* pPaintWindow = mpView->FindPaintWindow(*mpWindow);
+ Rectangle aVisArea;
+
+ if(pPaintWindow)
+ {
+ aVisArea = pPaintWindow->GetVisibleArea();
+ }
// offset vis area by edit engine left-top position
SdrTextObj* pTextObj = PTR_CAST( SdrTextObj, mpObject );
@@ -818,7 +825,7 @@ SvxEditViewForwarder* SvxTextEditSourceImpl::GetEditViewForwarder( sal_Bool bCre
{
// destroy all forwarders (no need for UpdateData(),
- // it's been synched on EndTextEdit)
+ // it's been synched on SdrEndTextEdit)
delete mpViewForwarder;
mpViewForwarder = NULL;
@@ -851,9 +859,9 @@ SvxEditViewForwarder* SvxTextEditSourceImpl::GetEditViewForwarder( sal_Bool bCre
else
{
- // failure. Somehow, BegTextEdit did not set
+ // failure. Somehow, SdrBeginTextEdit did not set
// our SdrTextObj into edit mode
@@ -869,7 +877,7 @@ void SvxTextEditSourceImpl::UpdateData()
// DrawOutliner. Thus, all changes made on the text forwarder are
// reflected on the view and committed to the model on
- // EndTextEdit(). Thus, no need for explicit updates here.
+ // SdrEndTextEdit(). Thus, no need for explicit updates here.
if( !HasView() || !IsEditMode() )
{